==> jc-1.4.0.tar.gz: soot/coffi/CONSTANT__5fUtf8__5fcollector.h <==
// public class soot.coffi.CONSTANT_Utf8_collector

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 520ca60a5838d95e soot_coffi_CONSTANT__5fUtf8__5fcollector

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_CONSTANT__5fUtf8__5fcollector_H_
#define _JC_soot_coffi_CONSTANT__5fUtf8__5fcollector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object;
struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object;

// Typedefs
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object;

typedef const struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods;
typedef const struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable;
typedef const struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype;

// Constructors
extern void _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object *_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method$add$71773a896e7a9efb(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method_info$add$71773a896e7a9efb;

// Static methods
extern struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method$v$9b2403f17ded80b4(_jc_env *);

// Virtual methods structure
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods {
	struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object	*(*add$71773a896e7a9efb)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object *);
};

// Vtable
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods	soot_coffi_CONSTANT__5fUtf8__5fcollector;
};

// Vtype
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype {
	_jc_type			type;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs {
	struct _jc_java_util_HashMap$object	*hash;
};

// Reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs {
    _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs	soot_coffi_CONSTANT__5fUtf8__5fcollector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs	soot_coffi_CONSTANT__5fUtf8__5fcollector;
};

// Object instance structure
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object {
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype	*vtype;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_CONSTANT__5fUtf8__5fcollector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$class_object;

#endif	/* _JC_soot_coffi_CONSTANT__5fUtf8__5fcollector_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/CONSTANT__5fUtf8__5fcollector.h <==
// public class soot.coffi.CONSTANT_Utf8_collector

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 520ca60a5838d95e soot_coffi_CONSTANT__5fUtf8__5fcollector

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_CONSTANT__5fUtf8__5fcollector_H_
#define _JC_soot_coffi_CONSTANT__5fUtf8__5fcollector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object;
struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object;

// Typedefs
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs;
typedef struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object;

typedef const struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods;
typedef const struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable;
typedef const struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype;

// Constructors
extern void _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object *_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method$add$71773a896e7a9efb(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method_info$add$71773a896e7a9efb;

// Static methods
extern struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$method$v$9b2403f17ded80b4(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods {
	struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object	*(*add$71773a896e7a9efb)(_jc_env *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object *, struct _jc_soot_coffi_CONSTANT__5fUtf8__5finfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vmethods	soot_coffi_CONSTANT__5fUtf8__5fcollector;
};

// Vtype
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype {
	_jc_type			type;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs {
	struct _jc_java_util_HashMap$object	*hash;
};

// Reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs {
    _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_refs	soot_coffi_CONSTANT__5fUtf8__5fcollector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$sub_nonrefs	soot_coffi_CONSTANT__5fUtf8__5fcollector;
};

// Object instance structure
struct _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$object {
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype	*vtype;
	_jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$vtype _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_CONSTANT__5fUtf8__5fcollector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_CONSTANT__5fUtf8__5fcollector$class_object;

#endif	/* _JC_soot_coffi_CONSTANT__5fUtf8__5fcollector_H_ */
